| 33 | // transpose a matrix |
| 34 | template <typename T> |
| 35 | void sym(T* out, const T* in, size_s mat_size) { |
| 36 | dim3 blockDim(32, 32); |
| 37 | dim3 gridDim((mat_size + blockDim.x - 1) / blockDim.x, (mat_size + blockDim.y - 1) / blockDim.y); |
| 38 | symKernel<<<gridDim, blockDim>>>(out, in, mat_size); |
| 39 | } |
| 40 | |
| 41 | template <typename T> |
| 42 | __global__ void symBatchedKernel(T* out, const T* in, size_s mat_size, size_s batch_size) { |
nothing calls this directly
no outgoing calls
no test coverage detected